Learn R Programming

ggarchery (version 0.4.4)

attract_by_distance: Move points towards each other an absolute distance

Description

Move points towards each other an absolute distance

Usage

attract_by_distance(x, xend, y, yend, length_start, length_end)

Value

A named list of new coordinates for the start and end of the line

Arguments

x, xend, y, yend

The coordinates of the start and end of the segment

length_start, length_end

How much to take off the start and end of the line (in the units of the data; beware this can make little sense unless both axes have the same units)