Learn R Programming

ggarchery (version 0.4.4)

attract_proportionally: Move points towards each other a proportion of the distance between them

Description

Move points towards each other a proportion of the distance between them

Usage

attract_proportionally(x, xend, y, yend, prop_start, prop_end)

Value

A named list of new coordinates for the start and end of the line

Arguments

x, xend, y, yend

The coordinates of the start and end of the segment

prop_start, prop_end

How much (proportionally) to take off the start and end of the line