Move points towards each other an absolute distance
attract_by_distance(x, xend, y, yend, length_start, length_end)A named list of new coordinates for the start and end of the line
The coordinates of the start and end of the segment
How much to take off the start and end of the line (in the units of the data; beware this can make little sense unless both axes have the same units)